(*  GREATIS DEVICE CAPABILITIES                            *)
(*  Copyright (C) 2005-2014 Greatis Software               *)
(*                                                         *)
(*  http://www.greatis.com/delphicb/devicecaps/            *)

unit Main;

interface

uses
  Windows, Messages, SysUtils, Classes, Graphics, Controls, Forms, Dialogs,
  DeviceCapabilities, StdCtrls, ShellAPI;

type
  TfrmMain = class(TForm)
    DC: TDeviceCapabilities;
    lblDisplay: TLabel;
    lblPrinter: TLabel;
    memDisplay: TMemo;
    memPrinter: TMemo;
    btnMore: TButton;
    btnClose: TButton;
    procedure FormShow(Sender: TObject);
    procedure FormCreate(Sender: TObject);
    procedure btnMoreClick(Sender: TObject);
    procedure btnCloseClick(Sender: TObject);
  private
    { Private declarations }
    function GetCapsText: string;
  public
    { Public declarations }
  end;

var
  frmMain: TfrmMain;

implementation

{$R *.DFM}

function TfrmMain.GetCapsText: string;
var
  S: string;
begin
  with DC do
  begin
    Result:='Driver version: '+IntToStr(DriverVersion);
    Result:=Result+#13#10'Device technology: ';
    case Technology of
      dtVectorPlotter: Result:=Result+'Vector plotter';
      dtRasterDisplay: Result:=Result+'Raster display';
      dtRasterPrinter: Result:=Result+'Raster printer';
      dtRasterCamera: Result:=Result+'Raster camera';
      dtCharacterStream: Result:=Result+'Character stream';
      dtMetafile: Result:=Result+'Metafile';
    else Result:=Result+'Display file';
    end;
    Result:=Result+#13#10'Horizontal size: '+IntToStr(HorzSize)+' mm';
    Result:=Result+#13#10'Vertical size: '+IntToStr(VertSize)+' mm';
    Result:=Result+#13#10'Horizontal resolution: '+IntToStr(HorzRes)+' pix';
    Result:=Result+#13#10'Vertical resolution: '+IntToStr(VertRes)+' pix';
    Result:=Result+#13#10'Horizontal pixels per inch: '+IntToStr(LogPixelsX);
    Result:=Result+#13#10'Vertical pixels per inch: '+IntToStr(LogPixelsX);
    Result:=Result+#13#10'Bits for pixel: '+IntToStr(BitsPixel);
    Result:=Result+#13#10'Color planes: '+IntToStr(ColorPlanes);
    Result:=Result+#13#10'Number of device-specific brushes: '+IntToStr(NumBrushes);
    Result:=Result+#13#10'Number of device-specific pens: '+IntToStr(NumPens);
    Result:=Result+#13#10'Number of device-specific fonts: '+IntToStr(NumFonts);
    Result:=Result+#13#10'Number of entries in color table: '+IntToStr(NumColors);
    Result:=Result+#13#10'Relative width of a device pixel: '+IntToStr(AspectX);
    Result:=Result+#13#10'Relative height of a device pixel: '+IntToStr(AspectY);
    Result:=Result+#13#10'Diagonal size of the device pixel: '+IntToStr(AspectXY);
    Result:=Result+#13#10'Clipping capabilities: ';
    if ClipCaps then Result:=Result+'Yes' else Result:=Result+'No';
    Result:=Result+#13#10'Number of entries in the system palette: '+IntToStr(SizePalette);
    Result:=Result+#13#10'Color resolution: '+IntToStr(ColorRes)+' bits per pixel';
    Result:=Result+#13#10'Width of physical page: '+IntToStr(PhysicalWidth)+' device units';
    Result:=Result+#13#10'Height of physical page: '+IntToStr(PhysicalHeight)+' device units';
    Result:=Result+#13#10'Horizontal offset of printable area: '+IntToStr(PhysicalOffsetX)+' device units';
    Result:=Result+#13#10'Vertical offset of printable area: '+IntToStr(PhysicalOffsetY)+' device units';
    Result:=Result+#13#10'Vertical refresh rate: '+IntToStr(VRefresh)+' Hz';
    Result:=Result+#13#10'X-axis scaling factor of the printer: '+IntToStr(ScalingFactorX);
    Result:=Result+#13#10'Y-axis scaling factor of the printer: '+IntToStr(ScalingFactorY);
    Result:=Result+#13#10'Preferred horizontal drawing alignment: '+IntToStr(BltAlignment)+' pix';
    Result:=Result+#13#10#13#10'Shading and blending capabilities: ';
    S:='';
    if sbConstAlpha in ShadingBlendingCaps then S:=S+'handles the SourceConstantAlpha member, ';
    if sbPixelAlpha in ShadingBlendingCaps then S:=S+'capable of doing GradientFill rectangles, ';
    if sbRemultAlpha in ShadingBlendingCaps then S:=S+'capable of doing GradientFill triangles, ';
    if sbGradRect in ShadingBlendingCaps then S:=S+'capable of handling per-pixel alpha in AlphaBlend, ';
    if sbGradTri in ShadingBlendingCaps then S:=S+'capable of handling premultiplied alpha in AlphaBlend, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Raster capabilities: capable of ';
    S:='';
    if rcBanding in RasterCaps then S:=S+'requires banding support, ';
    if rcBitBlt in RasterCaps then S:=S+'transferring bitmaps, ';
    if rcBitmap64 in RasterCaps then S:=S+'supporting bitmaps larger than 64 KB, ';
    if rcDiBitmap in RasterCaps then S:=S+'supporting the SetDIBits and GetDIBits functions, ';
    if rcDibToDev in RasterCaps then S:=S+'supporting the SetDIBitsToDevice function, ';
    if rcFloodFill in RasterCaps then S:=S+'performing flood fills, ';
    if rcPalette in RasterCaps then S:=S+'specifies a palette-based device, ';
    if rcScaling in RasterCaps then S:=S+'scaling, ';
    if rcStretchBlt in RasterCaps then S:=S+'performing the StretchBlt function, ';
    if rcStretchDib in RasterCaps then S:=S+'performing the StretchDIBits function, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Curve capabilities: can draw ';
    S:='';
    if ccChord in CurveCaps then S:=S+'chord arcs, ';
    if ccCircles in CurveCaps then S:=S+'circles, ';
    if ccEllipses in CurveCaps then S:=S+'ellipses, ';
    if ccInteriors in CurveCaps then S:=S+'interiors, ';
    if ccPie in CurveCaps then S:=S+'pie wedges, ';
    if ccRoundRect in CurveCaps then S:=S+'rounded rectangles, ';
    if ccStyled in CurveCaps then S:=S+'styled borders, ';
    if ccWide in CurveCaps then S:=S+'wide borders, ';
    if ccWideStyled in CurveCaps then S:=S+'borders that are wide and styled, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Line capabilities: can draw ';
    S:='';
    if lcInteriors in LineCaps then S:=S+'interiors, ';
    if lcMarker in LineCaps then S:=S+'a marker, ';
    if lcPolyline in LineCaps then S:=S+'a polyline, ';
    if lcPolymarker in LineCaps then S:=S+'multiple markers, ';
    if lcStyled in LineCaps then S:=S+'styled lines, ';
    if lcWide in LineCaps then S:=S+'wide lines, ';
    if lcWideStyled in LineCaps then S:=S+'lines that are wide and styled, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Polygon capabilities: can draw ';
    S:='';
    if pcInteriors in PolygonalCaps then S:=S+'interiors, ';
    if pcPolygon in PolygonalCaps then S:=S+'alternate-fill polygons, ';
    if pcRectangle in PolygonalCaps then S:=S+'rectangles, ';
    if pcScanLine in PolygonalCaps then S:=S+'single scanline, ';
    if pcStyled in PolygonalCaps then S:=S+'styled borders, ';
    if pcWide in PolygonalCaps then S:=S+'wide borders, ';
    if pcWideStyled in PolygonalCaps then S:=S+'borders that are wide and styled, ';
    if pcWindPolygon in PolygonalCaps then S:=S+'winding-fill polygons, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Text capabilities: ';
    S:='';
    if tcCharacterOutputPrecision in TextCaps then S:=S+'capable of character output precision, ';
    if tcStrokeOutputPrecision in TextCaps then S:=S+'capable of stroke output precision, ';
    if tcStrokeClipPrecision in TextCaps then S:=S+'capable of stroke clip precision, ';
    if tc90DegreeCharacterRotation in TextCaps then S:=S+'capable of 90-degree character rotation, ';
    if tcAnyCharacterRotation in TextCaps then S:=S+'capable of any character rotation, ';
    if tcXYIndependentlyScaling in TextCaps then S:=S+'can scale independently in the x- and y-directions, ';
    if tcDoubleCharacterScaling in TextCaps then S:=S+'capable of doubled character for scaling, ';
    if tcIntegerMultipleCharacterScaling in TextCaps then S:=S+'uses integer multiples only for character scaling, ';
    if tcAnyMultiplesCharacterScaling in TextCaps then S:=S+'uses any multiples for exact character scaling, ';
    if taBold in TextCaps then S:=S+'can draw double-weight characters, ';
    if taItalic in TextCaps then S:=S+'can italicize, ';
    if taUnderline in TextCaps then S:=S+'can underline, ';
    if taStrikeout in TextCaps then S:=S+'can draw strikeouts, ';
    if taRasterFonts in TextCaps then S:=S+'can draw raster fonts, ';
    if taVectorFonts in TextCaps then S:=S+'can draw vector fonts, ';
    if taScrollBlt in TextCaps then S:=S+'cannot scroll using a bit-block transfer, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
    Result:=Result+#13#10#13#10'Color management capabilities: ';
    S:='';
    if cmCMYKColor in ColorManagementCaps then S:=S+'can accept CMYK color space ICC color profile, ';
    if cmDeviceICM in ColorManagementCaps then S:=S+'can perform ICM on either the device driver or the device itself, ';
    if cmGammaRamp in ColorManagementCaps then S:=S+'supports GetDeviceGammaRamp and SetDeviceGammaRamp, ';
    if S<>'' then Result:=Result+Copy(S,1,Length(S)-2)
    else Result:=Result+'not supported';
  end;
end;

procedure TfrmMain.FormShow(Sender: TObject);
begin
  DC.CurrentDevice:=cdDisplay;
  memDisplay.Lines.Text:=GetCapsText;
  DC.CurrentDevice:=cdPrinter;
  memPrinter.Lines.Text:=GetCapsText;
end;


procedure TfrmMain.FormCreate(Sender: TObject);
var
  LF: TLogFont;
begin
  SystemParametersInfo(SPI_GETICONTITLELOGFONT,SizeOf(LF),@LF,0);
  with LF,Font do
  begin
    ScaleBy(Abs(lfHeight),Abs(Height));
    Handle:=CreateFontIndirect(LF);
  end;
end;

procedure TfrmMain.btnMoreClick(Sender: TObject);
begin
  ShellExecute(Handle,'open','http://www.greatis.com/delphicb/devicecaps/',nil,nil,SW_SHOWDEFAULT);
end;

procedure TfrmMain.btnCloseClick(Sender: TObject);
begin
  Application.Terminate;
end;

end.
